Alignment Functions
===================

Functions for aligning molecules based on their interaction profiles.

Main Alignment Module
---------------------

.. automodule:: shepherd_score.alignment
   :members:
   :undoc-members:
   :show-inheritance:

JAX Alignment
-------------

.. automodule:: shepherd_score.alignment_jax
   :members:
   :undoc-members:
   :show-inheritance:

Alignment Utilities
-------------------

SE3 Transformations (PyTorch)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.alignment_utils.se3
   :members:
   :undoc-members:
   :show-inheritance:

SE3 Transformations (NumPy)
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.alignment_utils.se3_np
   :members:
   :undoc-members:
   :show-inheritance:

SE3 Transformations (JAX)
~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.alignment_utils.se3_jax
   :members:
   :undoc-members:
   :show-inheritance:

PCA Utilities (PyTorch)
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.alignment_utils.pca
   :members:
   :undoc-members:
   :show-inheritance:

PCA Utilities (NumPy)
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.alignment_utils.pca_np
   :members:
   :undoc-members:
   :show-inheritance:

PCA Utilities (JAX)
~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.alignment_utils.pca_jax
   :members:
   :undoc-members:
   :show-inheritance:
